import React from 'react';
import { BarChart, Bar, Cell, XAxis, YAxis, Tooltip, Legend, ResponsiveContainer } from 'recharts';

export const DetailsBars = props => {
	const {
		data,
		labels,
		onClick,
		compact
	} = props;
	if (!Array.isArray(data))
		return null;

	const barGap = 5;
	const barSize = 56;
	const chartHeight = data.length * (barSize + barGap * 2);
	const hasClickHandler = typeof onClick == 'function';

	return (
		<>
			{typeof labels == 'object' && labels ? (
				<div className="row mb-2 text-center">
					<div className={compact ? 'col-5 offset-7' : 'col-3 offset-9'}>
						<div className="row mx-n1">
							<div className="col-4 px-1">
								<span className="badge badge-pill badge-secondary text-white">
									{labels.fact}
								</span>
							</div>
							<div className="col-4 px-1">
								<span className="badge badge-pill badge-secondary text-white">
									{labels.plan}
								</span>
							</div>
							<div className="col-4 px-1">
								<span className="badge badge-pill badge-secondary text-white">
									{labels.percent}
								</span>
							</div>
						</div>
					</div>
				</div>
			) : null}
			<div
				className="row"
				style={{ height: `${chartHeight}px` }}
			>
				<div className={`${compact ? 'col-3' : 'col-2'} border-right border-secondary`}>
					{data.map((dataItem, dataItemIdx) => (
						<div
							key={dataItemIdx}
							className="d-flex align-items-center overflow-hidden fs-12"
							style={{
								height: `${barSize + barGap * 2}px`,
								padding: `${barGap * 2}px 0`
							}}
						>
							{hasClickHandler ? (
								<button type="button"
									className="button-inline text-reset"
									onClick={() => onClick(dataItem.id)}
								>
									{dataItem.name}
								</button>
							) : (
								dataItem.name
							)}
						</div>
					))}
				</div>
				<div className={`h-100 px-1 ${compact ? 'col-4' : 'col-7'} border-right border-secondary`}>
					<ResponsiveContainer width="100%" height="100%">
						<BarChart
							data={data}
							layout="vertical"
							margin={{
								top: 0,
								right: 0,
								left: 0,
								bottom: 0,
							}}
							barCategoryGap={barGap}
							barGap={barGap * 2}
						>
							<XAxis
								type="number"
								hide={true}
							/>
							<YAxis
								type="category"
								domain={['dataMin', 'dataMax']}
								hide={true}
							/>
							<Bar
								dataKey="fact"
								fill="#7852FB"
								radius={[0, 10, 10, 0]}
								name={typeof labels == 'object' && labels && "fact" in labels ? labels.fact : ""}
								onClick={hasClickHandler ? data => onClick(data.id) : undefined}
								cursor={hasClickHandler ? "pointer" : undefined}
							>
								{data.map((dataItem, dataItemIdx) => (
									<Cell key={dataItemIdx} fill={dataItem.fact >= dataItem.plan ? '#7852FB' : '#FF5722' }/>
								))}
							</Bar>
						</BarChart>
					</ResponsiveContainer>
				</div>
				<div className={`${compact ? 'col-5' : 'col-3'} text-center text-primary font-weight-bold`}>
					{data.map((dataItem, dataItemIdx) => (
						<div
							key={dataItemIdx}
							className="row mx-n1 align-items-center"
							style={{
								height: `${barSize + barGap * 2}px`,
								padding: `${barGap * 2}px 0`
							}}
						>
							<div className="col-4 px-1">
								{dataItem.fact > 0 ? parseInt(dataItem.fact).toLocaleString('ru') : 0}
							</div>
							<div className="col-4 px-1">
								{dataItem.plan > 0 ? parseInt(dataItem.plan).toLocaleString('ru') : 0}
							</div>
							<div className="col-4 px-1">
								{dataItem.percent > 0 ? parseInt(dataItem.percent).toLocaleString('ru') : 0}%
								{"dynamic" in dataItem && (
									<span className={`ml-1 text-${dataItem.dynamic != 'negative' ? 'success' : 'danger'}`}>
										{dataItem.dynamic != 'negative' ? <>&uarr;</> : <>&darr;</>}
									</span>
								)}
							</div>
						</div>
					))}
				</div>
			</div>
		</>
	);
}