import React from 'react';
import { BarChart, Bar, ReferenceLine, ReferenceArea, XAxis, YAxis, ResponsiveContainer } from 'recharts';

export const HorizontalBars = props => {
	const {
		headers,
		referenceLines,
		data,
		onClick
	} = props;
	const barSize = 56;
	const barGap = 5;
	const chartHeight = (Array.isArray(data) ? data.length * (barSize + barGap * 2) : 0);
	const makeHandleClick = bar => (data, index) => {
		if (typeof onClick == 'function')
			return onClick(`${data.payload.id}-${bar}`);
	};

	return (
		<>
			{typeof headers == 'object' && headers ? (
				<div className="row mb-2">
					<div className="col-6 text-right">
						{'left' in headers && headers.left ? <h3 className="fs-15">{headers.left}</h3> : null}
					</div>
					<div className="col-6">
						{'right' in headers && headers.right ? <h3 className="fs-15">{headers.right}</h3> : null}
					</div>
				</div>
			) : null}
			{chartHeight > 0 ? (
				<div
					className="row"
					style={{ height: `${chartHeight}px` }}
				>
					<div className="col-6 pr-1 h-100">
						<div className="row h-100">
							<div className="col-5">
								{data.map((dataItem, dataItemIdx) => (
									<div
										key={dataItemIdx}
										style={{
											height: `${barSize + barGap * 2}px`,
											padding: `${barGap * 2}px 0`
										}}
									>
										<div className="d-flex flex-column justify-content-center overflow-hidden text-right">
											<div className="fs-12 mb-1">
												{dataItem.leftLabel}
											</div>
											<div className="fs-16 text-primary font-weight-bold">
												{parseInt(dataItem.leftValue).toLocaleString('ru')}
											</div>
										</div>
									</div>
								))}
							</div>
							<div className="col-7 h-100">
								<ResponsiveContainer width="100%" height="100%">
									<BarChart
										data={data}
										layout="vertical"
										margin={{
											top: 0,
											right: 0,
											left: 0,
											bottom: 0,
										}}
										barCategoryGap={barGap}
										barGap={barGap}
									>
										<XAxis type="number" hide={true} reversed={true}/>
										<YAxis type="category" hide={true}/>
										<Bar
											dataKey="leftValue"
											fill="#36CA75"
											radius={[0, 10, 10, 0]}
											onClick={makeHandleClick('left')}
											cursor="pointer"
										/>
										{typeof referenceLines == 'object' && 'left' in referenceLines ? (
											<ReferenceLine
												x={referenceLines.left}
												isFront={true}
												stroke="#ffffff"
												fill="#FF9A7A"
												shape={props => {
													const {
														x1,
														x2,
														y1,
														y2,
														fill,
														stroke
													} = props;
													return (
														<rect
															x={Math.min(x1, x2) - 3}
															y={Math.min(y1, y2)}
															width={4}
															height={Math.abs(y1 - y2)}
															fill={fill}
															stroke={stroke}
															strokeWidth={2}
														/>
													);
												}}
											/>
										) : null}
									</BarChart>
								</ResponsiveContainer>
							</div>
						</div>
					</div>
					<div className="col-6 pl-1 h-100">
						<div className="row h-100">
							<div className="col-7 h-100">
								<ResponsiveContainer width="100%" height="100%">
									<BarChart
										data={data}
										layout="vertical"
										margin={{
											top: 0,
											right: 0,
											left: 0,
											bottom: 0,
										}}
										barCategoryGap={barGap}
										barGap={barGap}
									>
										<XAxis type="number" hide={true} />
										<YAxis type="category" hide={true}/> 
										<Bar
											dataKey="rightValue"
											fill="#7852FB"
											radius={[0, 10, 10, 0]}
											onClick={makeHandleClick('right')}
											cursor="pointer"
										/>
										{typeof referenceLines == 'object' && 'right' in referenceLines ? (
											<ReferenceLine
												x={referenceLines.right}
												isFront={true}
												stroke="#ffffff"
												fill="#FF9A7A"
												shape={props => {
													const {
														x1,
														x2,
														y1,
														y2,
														fill,
														stroke
													} = props;
													return (
														<rect
															x={Math.min(x1, x2) - 3}
															y={Math.min(y1, y2)}
															width={4}
															height={Math.abs(y1 - y2)}
															fill={fill}
															stroke={stroke}
															strokeWidth={2}
														/>
													);
												}}
											/>
										) : null}
									</BarChart>
								</ResponsiveContainer>
							</div>
							<div className="col-5">
								{data.map((dataItem, dataItemIdx) => (
									<div
										key={dataItemIdx}
										style={{
											height: `${barSize + barGap * 2}px`,
											padding: `${barGap * 2}px 0`
										}}
									>
										<div className="d-flex flex-column justify-content-center overflow-hidden text-right">
											<div className="fs-12 mb-1">
												{dataItem.rightLabel}
											</div>
											<div className="fs-16 text-primary font-weight-bold">
												{parseInt(dataItem.rightValue).toLocaleString('ru')}
											</div>
										</div>
									</div>
								))}
							</div>
						</div>
					</div>
				</div>
			) : (
				<div className='text-center py-3'>
					Данные недоступны
				</div>
			)}

{/*<div style={{height: '500px'}}>
<ResponsiveContainer width="100%" >
        <BarChart
          data={data2}
		  layout="vertical"
          margin={{
            top: 0,
            right: 0,
            left: 0,
            bottom: 0,
          }}
		  
		  barGap={80}
		  barCategoryGap={50}
        >

		 <XAxis type="number" hide={true} reversed={true}/> <YAxis type="category" hide={true}/> 
          <Bar
		  	dataKey="pv"
			  fill="#8884d8"
			   />
        </BarChart>
      </ResponsiveContainer>
		</div>*/}
		</>
	);
}