import React from 'react';
import { ComposedChart, Bar, Scatter, XAxis, YAxis, Tooltip, Legend, CartesianGrid, ResponsiveContainer } from 'recharts';

export const HorizontalEnvBars = props => {
	const {
		data,
		labels
	} = props;
	const barSize = 30;
	const barGap = 12;
	const marginHeight = 20;
	const chartHeight = (Array.isArray(data) ? data.length * (barSize + barGap * 2) + marginHeight : 0);

	return (chartHeight > 0 ? (
		<div
			className="row"
			style={{ height: `${chartHeight}px` }}
		>
			<div className="col-2 text-right">
				{data.map((dataItem, dataItemIdx) => (
					<div
						key={dataItemIdx}
						style={{
							height: `${barSize + barGap * 2}px`,
							padding: `16px 0`
						}}
					>
						{dataItem.name}
					</div>
				))}
			</div>
			<div className="col-8 h-100">
				<ResponsiveContainer width="100%" height="100%">
					<ComposedChart
						data={data}
						layout="vertical"
						margin={{
							top: 0,
							right: 0,
							left: 0,
							bottom: 0,
						}}
						barCategoryGap={barGap}
						barGap={barGap}
					>
						<XAxis type="number" hide={true}/>
						<YAxis type="category" hide={true} dataKey="name"/>
						<CartesianGrid strokeDasharray="3 3" vertical={false} />
						<Bar
							dataKey="finished"
							fill="#36CA75"
							name={typeof labels == 'object' && labels && labels.finished}
							radius={[4, 4, 4, 4]}
						/>
						<Scatter
							dataKey="potential"
							fill="#3E60FD"
							stroke="#ffffff"
							name={typeof labels == 'object' && labels && labels.potential}
							shape={props => {
								const {
									cx,
									cy,
									fill,
									stroke
								} =  props;
								return (
									<rect
										x={cx - 5}
										y={cy - 26}
										width="10"
										height="52"
										rx="5"
										ry="5"
										fill={fill}
										stroke={stroke}
										strokeWidth="2"
									/>
								);
							}}
						/>
						<Tooltip />
						<Legend height={marginHeight}/>
					</ComposedChart>
				</ResponsiveContainer>
			</div>
			<div className="col-2 text-right">
				{data.map((dataItem, dataItemIdx) => (
					<div
						key={dataItemIdx}
						style={{
							height: `${barSize + barGap * 2}px`,
							padding: `5px`
						}}
					>
						<b
							className="val-badge bg-success text-white mr-2"
						>
							{dataItem.finished}
						</b>
						<b
							className="val-badge bg-info text-white"
						>
							{dataItem.potential}
						</b>
					</div>
				))}
			</div>
		</div>
	) : (
		<div className='text-center py-3'>
			Данные недоступны
		</div>
	));
}