import React from 'react';
import { ComposedChart, PieChart, Bar, Area, Line, Pie, Cell, XAxis, YAxis, Tooltip, Legend, CartesianGrid, ResponsiveContainer } from 'recharts';

export const StatBars = props => {
	const {
		className,
		title,
		dynamic,
		total,
		totalDetails,
		labels,
		data
	} = props;
	const isPositiveDynamic = (dynamic != 'negative');
	const hasData = Array.isArray(data) && data.length > 0;
	const pieColors = [ '#5BDED8', '#3E60FD', '#7852FB', '#36CA75' ];
	return (
		<div
			className={`row align-items-center${className ? ` ${className}` : ''}`}
			style={hasData ? { height: '300px' } : undefined}
		>
			<div className="col-3">
				<div className="pane px-2 py-4 text-center">
					<div className="fs-15 mb-4">
						{title}
					</div>
					<div className={`fs-32 font-weight-bold text-${isPositiveDynamic ? 'success' : 'danger'}`}>
						{parseInt(total).toLocaleString('ru')}
						<sup className="fs-32">
							{isPositiveDynamic ? <>&#x25B4;</> : <>&#x25BE;</>}
						</sup>
					</div>
					{Array.isArray(totalDetails) && totalDetails.length > 0 && (
						<ResponsiveContainer width="100%" height={150}>
							<PieChart width="100%" height={150}>
								<Pie
									dataKey="value"
									nameKey="name"
									data={totalDetails}
									innerRadius={15}
								>
									{totalDetails.map((dataItem, dataItemIdx) => (
										<Cell
											key={`pie-part-${dataItemIdx}`}
											fill={pieColors[dataItemIdx % pieColors.length]}
										/>
									))}
								</Pie>
								<Tooltip />
								<Legend />
							</PieChart>
						</ResponsiveContainer>
					)}
				</div>
			</div>
			<div className="col-9 h-100">
				{hasData ? (
					<ResponsiveContainer width="100%" height="100%">
						<ComposedChart
							data={data}
							margin={{
								top: 20,
								right: 0,
								left: 0,
								bottom: 0,
							}}
						>
							<XAxis dataKey="date" />
							<YAxis 
								yAxisId="value"
								stroke="#13E5DB"
							/>
							<YAxis
								yAxisId="total"
								stroke="#36CA75"
								orientation="right"
							/>
							<CartesianGrid strokeDasharray="3 3"/>
							<defs>
								<linearGradient id="colorTotal" x1="0" y1="0" x2="0" y2="1">
									<stop offset="5%" stopColor="#36CA75" stopOpacity={0.8}/>
									<stop offset="95%" stopColor="#36CA75" stopOpacity={0.2}/>
								</linearGradient>
							</defs>
							<Area
								type="monotone"
								dataKey="total"
								yAxisId="total"
								stroke="#36CA75"
								fillOpacity={1}
								fill="url(#colorTotal)"
								name={typeof labels == 'object' && labels && labels.total}
							/>
							<Bar
								dataKey="value"
								yAxisId="value"
								fill="#13E5DB"
								stroke="#ffffff"
								strokeWidth={2}
								radius={[4, 4, 4, 4]}
								label={{ position: 'insideBottom', fill: "#ffffff", fontSize: 12, formatter: v => parseInt(v).toLocaleString('ru') }}
								name={typeof labels == 'object' && labels && labels.value}
							/>
							<Line
								type="monotone"
								dataKey="plan"
								yAxisId="total"
								stroke="#FF5722"
								strokeWidth={2}
								dot={false}
								name={typeof labels == 'object' && labels && labels.plan}
							/>
							<Tooltip />
							<Legend />
						</ComposedChart>
					</ResponsiveContainer>
				) : (
					<div className="text-center">
						Данные недоступны
					</div>
				)}
			</div>
		</div>
	);
}