import React, { useState, useEffect } from 'react';
import { ComposedChart, Bar, Area, Line, Cell, XAxis, YAxis, Tooltip, Legend, CartesianGrid, ResponsiveContainer } from 'recharts';
import { Spinner } from '@/app/components/ui/Spinner';

export const StatBarsDetail = props => {
	const {
		id
	} = props;
	const [ ready, setReady ] = useState(false);
	const [ data, setData ] = useState([]);
	const [ labels, setLabels ] = useState({});
	useEffect(() => {
		fetch(`/data/screen2-prof-${id}.json`, {
			cache: 'no-store'
		}).then((response) => {
			return response.json();
		}).then((data) => {
			setData(data.data);
			setLabels(data.labels);
			setReady(true);
		}).catch(e => {});
	}, []);
	if (!ready) {
		return <Spinner />;
	}
	if (!Array.isArray(data) || data.length == 0) {
		return (
			<div className="text-center py-3">
				Данные недоступны
			</div>
		);
	}
	
	return (
		<ResponsiveContainer width="100%" height={300}>
			<ComposedChart
				data={data}
				margin={{
					top: 20,
					right: 0,
					left: 0,
					bottom: 0,
				}}
			>
				<XAxis dataKey="date" />
				<YAxis 
					yAxisId="value"
					stroke="#13E5DB"
				/>
				<YAxis
					yAxisId="total"
					stroke="#36CA75"
					orientation="right"
				/>
				<CartesianGrid strokeDasharray="3 3"/>
				<defs>
					<linearGradient id="colorTotal" x1="0" y1="0" x2="0" y2="1">
						<stop offset="5%" stopColor="#36CA75" stopOpacity={0.8}/>
						<stop offset="95%" stopColor="#36CA75" stopOpacity={0.2}/>
					</linearGradient>
				</defs>
				<Area
					type="monotone"
					dataKey="total"
					yAxisId="total"
					stroke="#36CA75"
					fillOpacity={1}
					fill="url(#colorTotal)"
					name={typeof labels == 'object' && labels && labels.total}
				/>
				<Bar
					dataKey="value"
					yAxisId="value"
					fill="#13E5DB"
					stroke="#ffffff"
					radius={[3, 3, 3, 3]}
					name={typeof labels == 'object' && labels && labels.value}
				/>
				<Line
					type="monotone"
					dataKey="plan"
					yAxisId="total"
					stroke="#FF5722"
					strokeWidth={2}
					dot={false}
					name={typeof labels == 'object' && labels && labels.plan}
				/>
				<Tooltip />
				<Legend />
			</ComposedChart>
		</ResponsiveContainer>
	);
}