import React, { useState } from 'react';
import { StatListTable } from '@/app/components/charts/StatListTable';

export const StatList = props => {
	const {
		labels,
		items
	} = props;
	const [ activeItems, setActiveItems ] = useState({});
	if (!Array.isArray(items))
		return null;
	const handleItemClick = itemIdx => {
		setActiveItems(st => {
			return {
				...st,
				[itemIdx]: !st[itemIdx]
			};
		});
	}
	return items.map((item, itemIdx) => {
		const isActive = !!activeItems[itemIdx];
		return (
			<div key={itemIdx} className="mb-2">
				<button
					type="button"
					className={`button-inline fs-18 text-${isActive ? 'primary' : 'reset'}`}
					onClick={() => handleItemClick(itemIdx)}
				>
					{isActive ? <>&#x25B4; </> : <>&#x25BE; </>}
					{item.title}
				</button>
				{isActive && (
					<StatListTable
						id={item.id}
						labels={labels}
					/>
				)}
				{isActive && Array.isArray(item.items) && (
					<table className="table table-striped table-sm mt-2 mb-4">
						{typeof labels == 'object' && labels && (
							<thead>
								<tr>
									<th>
										{labels.title}
									</th>
									<th>
										{labels.count}
									</th>
								</tr>
							</thead>
						)}
						<tbody>
							{item.items.map((tableItem, tableItemIdx) => {
								if (typeof tableItem != 'object' || !tableItem)
									return null;
								return (
									<tr key={tableItemIdx}>
										<td>
											{tableItem.title}
										</td>
										<td>
											{tableItem.count}
										</td>
									</tr>
								);
							})}
						</tbody>
					</table>
				)}
			</div>
		);
	});
}