import React, { useState, useEffect } from 'react';
import { Spinner } from '@/app/components/ui/Spinner';

export const StatListTable = props => {
	const {
		id,
		labels
	} = props;
	const [ ready, setReady ] = useState(false);
	const [ items, setItems ] = useState([]);
	useEffect(() => {
		fetch(`/data/screen2-problems-${id}.json`, {
			cache: 'no-store'
		}).then((response) => {
			return response.json();
		}).then((data) => {
			setItems(data.items);
			setReady(true);
		}).catch(e => {});
	}, []);
	if (!ready) {
		return <Spinner />;
	}
	if (!Array.isArray(items) || items.length == 0) {
		return (
			<div className='text-center py-3'>
				Данные недоступны
			</div>
		);
	}
	return (
		<table className="table table-sm mt-2 mb-4">
			{typeof labels == 'object' && labels && (
				<thead>
					<tr className="fs-12">
						<th>
							{labels.title}
						</th>
						<th className="text-center">
							{labels.count}
						</th>
						<th className="text-center">
							{labels.over}
						</th>
					</tr>
				</thead>
			)}
			<tbody>
				{items.map((tableItem, tableItemIdx) => {
					if (typeof tableItem != 'object' || !tableItem)
						return null;
					return (
						<tr key={tableItemIdx}>
							<td className="fs-12">
								{tableItem.title}
							</td>
							<td className="text-center text-danger font-weight-bold">
								{tableItem.count}
							</td>
							<td className="text-center text-danger font-weight-bold">
								{tableItem.over}
							</td>
						</tr>
					);
				})}
			</tbody>
		</table>
	);
}