import React, { useState, useEffect } from 'react';
import { Helmet } from "react-helmet";
import { Spinner } from '@/app/components/ui/Spinner';
import { HorizontalBars } from '@/app/components/charts/HorizontalBars';
import { DetailsBars } from '@/app/components/charts/DetailsBars';

export const Page1 = () => {
	const [ title, setTitle] = useState("Загрузка");
	const [ ready, setReady ] = useState(false);
	const [ mainData, setMainData ] = useState({});
	const [ details, setDetails ] = useState({});

	useEffect(() => {
		fetch('/data/screen1.json', {
			cache: 'no-store'
		}).then((response) => {
			return response.json();
		}).then((data) => {
			setTitle('title' in data ? data.title : '');
			setMainData(('main' in data && typeof data.main == 'object' && data.main) || {});
			setDetails(('details' in data && typeof data.details == 'object' && data.details) || {});
			setReady(true);
		}).catch(e => {});
	}, []);

	const [ currentDetails, setCurrentDetails ] = useState(null);
	const handleHorizontalBarClick = detailsId => setCurrentDetails(detailsId);

	return (
		<>
			<Helmet title={title} />
			{!ready ? (
				<Spinner />
			) : (
				<>
					<div className="pane">
						<HorizontalBars
							headers={mainData.headers}
							referenceLines={mainData.referenceLines}
							data={mainData.data}
							onClick={handleHorizontalBarClick}
						/>
					</div>
					{currentDetails ? (
						<div className="pane">
							{currentDetails in details ? ( 
								<>
									{'title' in details[currentDetails] && details[currentDetails].title ? (
										<h3 className="mb-4">{details[currentDetails].title}</h3>
									) : null}
									{'data' in details[currentDetails] ? (
										<DetailsBars
											data={details[currentDetails].data}
											labels={details[currentDetails].labels}
										/>
									) : (
										<div className="py-3 text-center">
											Данные недоступны
										</div>
									)}
								</>
							) : (
								<div className="py-3 text-center">
									Данные недоступны
								</div>
							)}
						</div>
					) : null}
				</>
			)}
		</>
	);
}