import React, { useState, useEffect, useRef } from 'react';
import { Helmet } from "react-helmet";
import { Spinner } from '@/app/components/ui/Spinner';
import { StatBars } from '@/app/components/charts/StatBars';
import { StatBarsDetail } from '@/app/components/charts/StatBarsDetail';
import { DetailsBars } from '@/app/components/charts/DetailsBars';
import { StatListTable } from '@/app/components/charts/StatListTable';
import { HorizontalEnvBars } from '@/app/components/charts/HorizontalEnvBars';

export const Page2 = () => {
	const [ title, setTitle] = useState("Загрузка");
	const [ profData, setProfData ] = useState({});
	const [ details, setDetails ] = useState({});
	const [ problems, setProblems ] = useState({});
	const [ environment, setEnvironment ] = useState({});
	const [ regionId, setRegionId ] = useState(null);
	const [ ready, setReady ] = useState(false);
	useEffect(() => {
		fetch('/data/screen2.json', {
			cache: 'no-store'
		}).then((response) => {
			return response.json();
		}).then((data) => {
			setTitle('title' in data ? data.title : '');
			setProfData(data.prof);
			setDetails(data.details);
			setProblems(data.problems);
			setEnvironment(data.environment);
			setReady(true);
		}).catch(e => {});
	}, []);
	const region = (regionId && 'data' in details && details.data.find(detail => detail.id == regionId)) || {};
	const detailsRef = useRef(null);

	return (
		<>
			<Helmet title={title} />
			{!ready ? (
				<Spinner />
			) : (
				<>
					{typeof environment == 'object' && environment ? (
						<div className="pane">
							{'title' in environment && (
								<h3 className="mb-4">
									{environment.title}
								</h3>
							)}
							{'data' in environment ? (
								<HorizontalEnvBars
									data={environment.data}
									labels={environment.labels}
								/>
							) : (
								<div className="py-3 text-center">
									Данные недоступны
								</div>
							)}
						</div>
					) : null}
					{typeof profData == 'object' && profData ? (
						<div className="pane">
							{'title' in profData && (
								<h3 className="mb-4">
									{profData.title}
								</h3>
							)}
							{'data' in profData ? (
								<StatBars
									title={profData.totalTitle}
									dynamic={profData.dynamic}
									total={profData.total}
									totalDetails={profData.totalDetails}
									labels={profData.labels}
									data={profData.data}
								/>
							) : (
								<div className="py-3 text-center">
									Данные недоступны
								</div>
							)}
						</div>
					) : null}
					{typeof details == 'object' && details && (
						<div className="pane" ref={detailsRef}>
							<div className="row">
								<div className={`col-lg-${regionId ? 6 : 12}`}>
									{'title' in details && (
										<h3 className="mb-4">
											{details.title}
										</h3>
									)}
									{'data' in details ? (
										<DetailsBars
											data={details.data}
											labels={details.labels}
											onClick={id => {
												setRegionId(id);
												detailsRef.current.scrollIntoView();
											}}
											compact={!!regionId}
										/>
									) : (
										<div className="py-3 text-center">
											Данные недоступны
										</div>
									)}
								</div>
								{regionId ? (
									<div className="col-lg-6">
										{'name' in region && region.name ? (
											<h3 className="mb-4">
												{region.name}
											</h3>
										) : null}
										<div className="pane">
											{'title' in problems && problems.title ? (
												<h3 className="mb-4">
													{problems.title}
												</h3>
											) : null}
											<StatListTable
												key={regionId}
												labels={problems.labels}
												id="region1"
											/>
										</div>
										<div className="pane">
											{'title' in profData && (
												<h3 className="mb-4">
													{profData.title}
												</h3>
											)}
											<StatBarsDetail
												key={`sd-${regionId}`}
												id="region1"
											/>
										</div>
									</div>
								) : null}
							</div>
						</div>
					)}
					
				</>
			)}
		</>
	);
}