import React, { useState, useEffect } from 'react';
import { Helmet } from "react-helmet";
import { Spinner } from '@/app/components/ui/Spinner';
import { Map } from '@/app/components/charts/Map';
import { Analytics } from '@/app/components/charts/Analytics';

export const Page3 = () => {
	const [ title, setTitle] = useState("Загрузка");
	const [ mapData, setMapData] = useState({});
	const [ regionId, setRegionId ] = useState(null);
	const [ ready, setReady ] = useState(false);
	useEffect(() => {
		fetch('/data/screen3.json', {
			cache: 'no-store'
		}).then((response) => {
			return response.json();
		}).then((data) => {
			setTitle('title' in data ? data.title : '');
			setMapData(data.map);
			setReady(true);
		}).catch(e => {});
	}, []);

	return (
		<>
			<Helmet title={title} />
			{!ready ? (
				<Spinner />
			) : (
				<>
					<div className="pane">
						{'title' in mapData && (
							<h3 className="mb-4">
								{mapData.title}
							</h3>
						)}
						<div className="row justify-content-center">
							<div className="col-lg-9">
								<Map
									labels={mapData.labels}
									data={mapData.data}
									onClick={id => setRegionId(id)}
								/>
							</div>
						</div>
					</div>
					{regionId ? (
						<Analytics
							key={regionId}
							id="region1"
						/>
					) : null}
				</>
			)}
		</>
	);
}